aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThanos Makatos <thanos.makatos@nutanix.com>2019-09-24 11:06:57 -0400
committerThanos <tmakatos@gmail.com>2019-09-27 15:59:11 +0100
commit1af64a775cb866e165f8c3ed749f84c321fb8ab8 (patch)
tree6c12b06a2fff94278b0380fde27eb5e326a339d8
parentf26e27f0556b713b9fcf9c1e689e991400abc0db (diff)
downloadlibvfio-user-1af64a775cb866e165f8c3ed749f84c321fb8ab8.zip
libvfio-user-1af64a775cb866e165f8c3ed749f84c321fb8ab8.tar.gz
libvfio-user-1af64a775cb866e165f8c3ed749f84c321fb8ab8.tar.bz2
clarify usage of lm_irq_trigger
Signed-off-by: Thanos Makatos <thanos.makatos@nutanix.com>
-rw-r--r--lib/muser.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/lib/muser.h b/lib/muser.h
index a62bc08..67050f4 100644
--- a/lib/muser.h
+++ b/lib/muser.h
@@ -341,12 +341,15 @@ int lm_ctx_run(lm_dev_info_t *dev_info);
/**
* Triggers an interrupt.
*
+ * libmuser takes care of using the IRQ type (INTx, MSI/X), the caller needs
+ * only specify to the sub-index.
+ *
* @lm_ctx: the libmuser context to trigger interrupt
* @vector: vector to trigger interrupt on
*
* @returns 0 on success, or -1 on failure. Sets errno.
*/
-int lm_irq_trigger(lm_ctx_t * lm_ctx, uint32_t vector);
+int lm_irq_trigger(lm_ctx_t * lm_ctx, uint32_t subindex);
/* Helper functions */
@@ -341,12 +341,15 @@ int lm_ctx_run(lm_dev_info_t *dev_info);
* @lm_ctx: the libmuser context to trigger interrupt
- * @vector: vector to trigger interrupt on
+ * @subindex: vector subindex to trigger interrupt on
*
* @returns 0 on success, or -1 on failure. Sets errno.